@@ -7,9 +7,20 @@ class MetricModel(object):
     stat (str, mandatory): The statistic to return
     unit (str): If you specify a unit, the operation returns only data that was collected with that unit specified
   """
-  def __init__(self, id, name, org_id, component_id, namespace,
-  alignment, region_name, agent, dimension_name=None, dimension_value=None,
-  is_active=False, description=None, unit=None):
+  def __init__(self,
+               id,
+               name,
+               org_id,
+               component_id,
+               namespace,
+               alignment,
+               region_name,
+               agent,
+               dimension_name=None,
+               dimension_value=None,
+               is_active=False,
+               description=None,
+               unit=None):
     self.id = id
     self.name = name
     self.org_id = org_id
@@ -21,31 +32,36 @@ class MetricModel(object):
     self.unit = unit
     self.description = description
     self.is_active = is_active
-    self.dimension_name = dimension_name,
+    self.dimension_name = dimension_name
     self.dimension_value = dimension_value
 
   def get_metric_name(self):
     return self.metric_name
 
+  def get_dimension_name(self):
+    return self.dimension_name
+
+  def update_is_active(self, is_active_value):
+    self.is_active = is_active_value
+
   def to_dict(self):
     """
     Returns a dict representation of a MetricModel instance for serialization.
     Returns:
       dict: Dict populated with self attributes to be serialized
     """
-    dictionary = dict(
-      id= self.id,
-      name=self.name,
-      org_id=self.org_id,
-      region_name=self.region_name,
-      namespace=self.namespace,
-      component_id=self.component_id,
-      agent=self.agent,
-      dimension_name=self.dimension_name,
-      dimension_value=self.dimension_value,
-      description=self.description,
-      metric_alignment=self.metric_alignment,
-      is_active=self.is_active)
+    dictionary = dict(id=self.id,
+                      name=self.name,
+                      org_id=self.org_id,
+                      region_name=self.region_name,
+                      namespace=self.namespace,
+                      component_id=self.component_id,
+                      agent=self.agent,
+                      dimension_name=self.dimension_name,
+                      dimension_value=self.dimension_value,
+                      description=self.description,
+                      alignment=self.alignment,
+                      is_active=self.is_active)
 
     if self.description is not None:
       dictionary.update(description=self.description)
