@@ -5,7 +5,7 @@ from botocore.config import Config
 
 def create_timestream_session(aws_access_key_id, aws_secret_access_key):
   region_name = 'eu-west-1'
-  session = boto3.Session(aws_access_key_id=aws_access_key_id, 
+  session = boto3.Session(aws_access_key_id=aws_access_key_id,
     aws_secret_access_key=aws_secret_access_key, region_name=region_name)
   return session
 
@@ -19,12 +19,12 @@ def prepare_metric_records(measure_name, measure_value, timestamp, dimensions):
     'MeasureName' : measure_name,
     'MeasureValue': str(measure_value),
     'MeasureValueType': 'DOUBLE'
-  } 
+  }
   return record
-  
+
 def write_to_timestream(records, database_name, table_name, ts_session):
   '''
-  Inserts a list of records into detech.ai's metrics 
+  Inserts a list of records into detech.ai's metrics
   '''
   write_client = ts_session.client('timestream-write', config=Config(
     read_timeout = 20, max_pool_connections=5000, retries={'max_attempts':5}
@@ -35,7 +35,7 @@ def write_to_timestream(records, database_name, table_name, ts_session):
     print("Processed %d records. WriteRecords Status: %s" %(len(records), status))
   except Exception as err:
     print("Error:", err)
-    raise Exception(err)
+    raise err
 
 def query_from_timestream(sql_query, database_name, table_name,ts_session):
   query_client = ts_session.client('timestream-query')
@@ -45,4 +45,3 @@ def query_from_timestream(sql_query, database_name, table_name,ts_session):
     print("Error:", err)
     raise Exception('Error: {}'.format(err))
   return response
-  
\ No newline at end of file
